==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/de_DE.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Starten Sie informiert in den Tag\n\nDas Nextcloud Dashboard ist Ihr Ausgangspunkt für den Tag und gibt Ihnen einen Überblick über Ihre anstehenden Termine, dringende E-Mails, Chatnachrichten, eingehende Tickets, neueste Tweets und vieles mehr! Benutzer können die gewünschten Widgets hinzufügen und den Hintergrund nach Belieben ändern.",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Alles Gute zum Geburtstag 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Alles Gute zum Geburtstag, {name} 🥳🤩🎂🎉",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the App Store" : "Holen Sie sich weitere Widgets aus dem App-Store",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem Nextcloud-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/de_DE.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Starten Sie informiert in den Tag\n\nDas Nextcloud Dashboard ist Ihr Ausgangspunkt für den Tag und gibt Ihnen einen Überblick über Ihre anstehenden Termine, dringende E-Mails, Chatnachrichten, eingehende Tickets, neueste Tweets und vieles mehr! Benutzer können die gewünschten Widgets hinzufügen und den Hintergrund nach Belieben ändern.",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Alles Gute zum Geburtstag 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Alles Gute zum Geburtstag, {name} 🥳🤩🎂🎉",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the App Store" : "Holen Sie sich weitere Widgets aus dem App-Store",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your {productName} server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem {productName}-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem Nextcloud-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält."
},
"nplurals=2; plural=(n != 1);");
